summaryrefslogtreecommitdiffstats
path: root/test/CodeGenOpenCL/builtins-r600.cl
diff options
context:
space:
mode:
authorMatt Arsenault <Matthew.Arsenault@amd.com>2016-07-15 21:33:02 +0000
committerMatt Arsenault <Matthew.Arsenault@amd.com>2016-07-15 21:33:02 +0000
commit34f54fad6b3739eebd879572dcc0261dc7e52eda (patch)
treec689668c4df74e727b8e487ebf68852a6f6eb143 /test/CodeGenOpenCL/builtins-r600.cl
parentab693fec046e5eb21ed4816c473bd72724209205 (diff)
AMDGPU: Update for rsq intrinsic changes
git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@275622 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'test/CodeGenOpenCL/builtins-r600.cl')
-rw-r--r--test/CodeGenOpenCL/builtins-r600.cl16
1 files changed, 8 insertions, 8 deletions
diff --git a/test/CodeGenOpenCL/builtins-r600.cl b/test/CodeGenOpenCL/builtins-r600.cl
index 0af663e6db..0951ff8182 100644
--- a/test/CodeGenOpenCL/builtins-r600.cl
+++ b/test/CodeGenOpenCL/builtins-r600.cl
@@ -1,19 +1,19 @@
// REQUIRES: amdgpu-registered-target
// RUN: %clang_cc1 -triple r600-unknown-unknown -target-cpu cypress -S -emit-llvm -o - %s | FileCheck %s
-// CHECK-LABEL: @test_rsq_f32
-// CHECK: call float @llvm.r600.rsq.f32
-void test_rsq_f32(global float* out, float a)
+// CHECK-LABEL: @test_recipsqrt_ieee_f32
+// CHECK: call float @llvm.r600.recipsqrt.ieee.f32
+void test_recipsqrt_ieee_f32(global float* out, float a)
{
- *out = __builtin_amdgpu_rsqf(a);
+ *out = __builtin_r600_recipsqrt_ieeef(a);
}
#if cl_khr_fp64
-// XCHECK-LABEL: @test_rsq_f64
-// XCHECK: call double @llvm.r600.rsq.f64
-void test_rsq_f64(global double* out, double a)
+// XCHECK-LABEL: @test_recipsqrt_ieee_f64
+// XCHECK: call double @llvm.r600.recipsqrt.ieee.f64
+void test_recipsqrt_ieee_f64(global double* out, double a)
{
- *out = __builtin_amdgpu_rsq(a);
+ *out = __builtin_r600_recipsqrt_ieee(a);
}
#endif